@@ -98,6 +98,10 @@ sub ban : Local {
     my $username = $c->req->param('username');
     my $user = $c->controller('Get')->user( $c, $username );
 
+    if ( $user->{status} eq 'banned' ) {
+        $c->detach( '/print_error', ['Already banned'] );
+    }
+
     $c->model('DBIC::User')->update_user( $user, { status => 'banned' } );
 
     $c->model('Log')->log_action(
@@ -118,7 +122,7 @@ __END__
 
 =pod
 
-=head2 AUTHOR
+=head1 AUTHOR
 
 Fayland Lam <fayland at gmail.com>
 
